You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nuttx.apache.org by xi...@apache.org on 2021/12/19 07:41:20 UTC

[incubator-nuttx] 02/05: eventfd: Fix the typo error

This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-nuttx.git

commit 8cb24a2964c882e77c39da3ee636ded2e425f1d6
Author: Xiang Xiao <xi...@xiaomi.com>
AuthorDate: Sat Dec 18 14:16:32 2021 +0800

    eventfd: Fix the typo error
    
    Signed-off-by: Xiang Xiao <xi...@xiaomi.com>
---
 fs/vfs/fs_eventfd.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/fs/vfs/fs_eventfd.c b/fs/vfs/fs_eventfd.c
index 38fce3d..ed924d2 100644
--- a/fs/vfs/fs_eventfd.c
+++ b/fs/vfs/fs_eventfd.c
@@ -41,7 +41,7 @@
  ****************************************************************************/
 
 #ifndef CONFIG_EVENT_FD_VFS_PATH
-#define CONFIG_EVENT_FD_VFS_PATH "/dev"
+#define CONFIG_EVENT_FD_VFS_PATH "/var/event"
 #endif
 
 #ifndef CONFIG_EVENT_FD_NPOLLWAITERS
@@ -226,9 +226,9 @@ static int eventfd_do_close(FAR struct file *filep)
   FAR struct inode *inode = filep->f_inode;
   FAR struct eventfd_priv_s *priv = inode->i_private;
 
   /* devpath: EVENT_FD_VFS_PATH + /efd (4) + %d (3) + null char (1) */
 
-  char devpath[sizeof(CONFIG_EVENT_FD_VFS_PATH) + 4 + 3 + 1];
+  char devpath[sizeof(CONFIG_EVENT_FD_VFS_PATH) + 4 + 10 + 1];
 
   /* Get exclusive access to the device structures */
@@ -226,9 +226,9 @@ static int eventfd_do_close(FAR struct file *filep)
   FAR struct eventfd_priv_s *priv = inode->i_private;
 
-  /* devpath: EVENT_FD_VFS_PATH + /efd (4) + %d (3) + null char (1) */
+  /* devpath: EVENT_FD_VFS_PATH + /efd (4) + %d (10) + null char (1) */
 